@@ -25,46 +25,20 @@
 
 static gchar *supported_mime_types[] = {
   "application/x-7z-compressed",
-  "application/x-7z-compressed-tar",
   "application/x-bzip",
-  "application/x-bzip-compressed-tar",
   "application/x-compress",
-  "application/x-compressed-tar",
   "application/x-cpio",
-  "application/x-gzip",
+  "application/gzip",
   "application/x-lha",
   "application/x-lzip",
-  "application/x-lzip-compressed-tar",
   "application/x-lzma",
-  "application/x-lzma-compressed-tar",
-  "application/x-rar",
   "application/x-tar",
-  "application/x-tarz",
   "application/x-xar",
   "application/x-xz",
-  "application/x-xz-compressed-tar",
   "application/zip",
   "application/gzip",
-  "application/bzip2",
-  NULL
 };
 
-static GHashTable *supported_mime_types_table = NULL;
-
-static void
-initialize_supported_mime_types_table (void)
-{
-  int i;
-
-  supported_mime_types_table = g_hash_table_new (g_str_hash,
-                                                 g_str_equal);
-
-  for (i = 0; supported_mime_types[i] != NULL; ++i) {
-    g_hash_table_add (supported_mime_types_table,
-                      supported_mime_types[i]);
-  }
-}
-
 /**
  * autoar_check_mime_type_supported:
  * @mime_type: a string representing the mime type
@@ -77,11 +51,17 @@ initialize_supported_mime_types_table (void)
 gboolean
 autoar_check_mime_type_supported (const gchar *mime_type)
 {
-  if (supported_mime_types_table == NULL) {
-    initialize_supported_mime_types_table ();
+  gint i;
+  gboolean supported = FALSE;
+
+  for (i = 0; i < G_N_ELEMENTS (supported_mime_types); i++) {
+    if (g_content_type_is_a (mime_type, supported_mime_types[i])) {
+      supported = TRUE;
+      break;
+    }
   }
 
-  return g_hash_table_contains (supported_mime_types_table, mime_type);
+  return supported;
 }
 
 /**
